.. _morphology:

*************************************************
Morphology and PSF methods (`gammapy.morphology`)
*************************************************

.. currentmodule:: gammapy.morphology

Introduction
============

`gammapy.morphology` contains functions and classes for morphology and PSF computations.

TODO: write me

Getting Started
===============

TODO: write me

Reference/API
=============

.. automodapi:: gammapy.morphology
    :no-inheritance-diagram:
